EmpaticaPlugin class

Constructors

EmpaticaPlugin()

Properties

dataEventSink → Stream<EmpaticaDataEvent>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ EmpaStatus
The EmpaStatus of the device. For example, ready, connected, disconnected, etc.
getter/setter pair
statusEventSink → Stream<EmpaticaStatusEvent>?
no setter

Methods

authenticateWithAPIKey(String key) → Future<void>
Initiates a connection to the Empatica backend using an API key given by Empatica.
cancelConnection() → Future<void>
Cancels the connection. Same as disconnect but also makes sure the EmpaStatus DISCONNECTED is sent on the Status stream.
cleanUp() → Future<void>
Cleans the Android context
connectDevice(String serialNumber) → Future<void>
Connects to the device with the serial number. Suitably call this whenever one has found a device from startScanning
disconnect() → Future<void>
Disconnects from the currently active Empatica device
getActiveDevice() → Future<String>
Returns the hardware MAC address of the currently connected device
getSessionIdCookie() → Future<String>
Get the HTTP cookie from this session
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyDisconnected() → Future<void>
Sends the EmpaStatus DISCONNECTED on the status stream.
startScanning() → Future<void>
Starts scanning for Empatica devices once the EmpaStatus.ready is thrown.
stopScanning() → Future<void>
Stops the scanning for devices started by startScanning. Suitably call this whenever one has connected to the device using connectDevice.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited