UpdateSensorStatus class

Inheritance

Constructors

UpdateSensorStatus(String type, String sensorType, int status)
UpdateSensorStatus.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensorType → String
final
status → int
final
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited